# farmOS Trademark Guidelines

Version 1.0, November 2016

## Introduction

This document, the "Policy," outlines the farmOS project's (the "Project")
policy for the use of our trademarks. While our software is available under a
free and open source software license, the copyright license does not include an
implied right or license to use our trademark.

The role of trademarks is to provide assurance about the quality of the products
or services with which the trademark is associated. But because an open source
license allows your unrestricted modification of the copyrighted software, we
cannot be sure that your modifications to the software are ones that will not be
misleading if distributed under the same name. Instead, this Policy describes
the circumstances under which you may use our trademarks.

In this Policy we are not trying to limit the lawful use of our trademarks, but
rather describe for you what we consider the parameters of lawful use to be.
Trademark law can be ambiguous, so we hope to provide enough clarity for you to
understand whether we will consider your use licensed or non-infringing.

The sections that follow describe what trademarks are covered by this Policy, as
well as uses of the trademarks that are allowed without additional permission
from us. If you want to use our trademarks in ways that are not described in
this Policy, please see "Where to get further information" below for contact
information. Any use that does not comply with this Policy or for which we have
not separately provided written permission is not a use that we have approved,
so you must decide for yourself whether the use is nevertheless lawful.

## Our commitment to open source principles

We want to encourage and facilitate the use of our trademarks by the community,
but do so in a way that still ensures that the trademarks are meaningful as a
source and quality indicator for our software and the associated goods and
services and continue to embody the high reputation of the software and the
community associated with it. This Policy therefore tries to strike the proper
balance between: 1) our need to ensure that our trademarks remain reliable
indicators of the qualities that they are meant to preserve and 2) our community
members' desire to be full participants in the Project.

## Trademarks subject to the guidelines

### Our trademarks

This Policy covers:

1. Our word trademarks and service marks (the "Word Marks"):

| Mark   | Common descriptive name for the goods or services |
| ------ | ------------------------------------------------- |
| farmOS | Computer software for use in farm planning and management |

2. Our logos (the "Logos"):

![farmOS](/img/farmOS.png)

3. And the unique visual styling of our website and packaging (the "Trade
Dress").

This Policy encompasses all trademarks and service marks, whether Word Marks,
Logos or Trade Dress, which are collectively referred to as the “Marks.” Some
Marks may not be registered, but registration does not equal ownership of
trademarks. This Policy covers our Marks whether they are registered or not.

## Universal considerations for all uses

Whenever you use one of the Marks, you must always do so in a way that does not
mislead anyone, either directly or by omission, about exactly what they are
getting and from whom. The law reflects this requirement in two major ways
described in more detail below: it prohibits creating a "likelihood of
confusion" but allows for "nominative use." For example, you cannot say you are
distributing the farmOS software when you're distributing a modified version of
it, because people would be confused when they are not getting the same features
and functionality they would get if they downloaded the software directly from
us. You also cannot use our logo on your website in a way that suggests that
your website is an official website or that we endorse your website. You can,
though, say you like the farmOS software, that you participate in the farmOS
community, that you are providing an unmodified version of the farmOS software,
or that you wrote a book describing how to use the farmOS software.

This fundamental requirement, that it is always clear to people what they are
getting and from whom, is reflected throughout this Policy. It should also serve
as your guide if you are not sure about how you are using the Marks.

In addition:

* You may not use the Marks in association with the use or distribution of
software if you are also not in compliance with the copyright license for the
software.
* You may not use or register, in whole or in part, the Marks as part of your own
trademark, service mark, domain name, company name, trade name, product name or
service name.
* Trademark law does not allow your use of names or trademarks that are too
similar to ours. You therefore may not use an obvious variation of any of our
Marks or any phonetic equivalent, foreign language equivalent, takeoff, or
abbreviation for a similar or compatible product or service. We would consider
the following too similar to one of our Marks:
    * Any mark beginning or ending with the letters FARMOS

You agree that you will not acquire any rights in the Marks and that any
goodwill generated by your use of the Marks inures solely to our benefit.

## Use for software

See [Universal considerations for all uses], above, which also apply.

### Uses we consider non-infringing

#### Distribution of unmodified source code or unmodified executable code we have compiled

When you redistribute an unmodified copy of our software, you are not changing
the quality or nature of it. Therefore, you may retain the Word Marks and the
Logos we have placed on the software to identify your redistribution -- whether
that redistribution is made by optical media, memory stick or download of
unmodified source and executable code. This kind of use only applied if you are
redistributing an official distribution from this Project that has not been
changed in any way. You can find files for the Logos and approved designs for
packaging on farmOS.org.

#### Distribution of executable code that you have compiled, or modified code

You may use the Word Marks, but not the Logos, to truthfully describe the origin
of the software that you are providing, that is, that the code you are
distributing is a modification of our software. You may say, for example, that
"this software is derived from the source code for farmOS software."

You will need to remove the Logo data files.

Of course, you can place your own trademarks or logos on versions of the
software to which you have made substantive modifications, because by modifying
the software you have become the origin of that exact version. In that case, you
should not use our Logos.

#### Statements about compatibility, interoperability or derivation

You may use the Word Marks, but not the Logos, to truthfully describe the
relationship between your software and ours. Our Mark should be used after a
verb or preposition that describes the relationship between your software and
ours. So you may say, for example, "Bob's software for the farmOS platform" but
may not say "Bob's farmOS software." Some other examples that may work for you
are:

* [Your software] works with farmOS software
* [Your software] uses farmOS software
* [Your software] is compatible with farmOS software
* [Your software] is powered by farmOS software
* [Your software] runs on farmOS software
* [Your software] for use with farmOS software
* [Your software] for farmOS software

#### Use of trademarks to show community affiliation

This section discusses the use of our Marks for software such an application
themes, skins and personas. The use of our Marks on websites is discussed below.

You may use the Word Marks and the Logos in themes, personas, or skins for
applications to show your support for the Project, provided that the use is
non-commercial and the use is clearly decorative, as contrasted with a use that
appears to be the branding for a website or application.

### Uses for which we are granting a license

#### Distribution of modified software

You may use the Word Marks and the Logos for the distribution of code (source or
executable) on the condition that any executable is built from the official
Project source code and that any modifications are limited to switching on or
off features already included in the software, translations into other
languages, and incorporating bug-fix patches.

#### Distribution of software preloaded on hardware

You may use the Word Marks and the Logos in association with hardware devices on
the condition that the executable installed on the device is the official source
executable for the Project, and that you do not suggest that the Project is the
source of the hardware device itself but rather than the Marks are for the
software incorporated into the device.

### Uses we consider infringing without seeking further permission from us

We will likely consider using the Marks in a software distribution that combines
our software with any other software program an infringement of our Marks. We
would consider your software "combined" with ours if you create a single
executable for both software programs, as well as if by installing our software
it automatically installs yours. We would not consider your software "combined"
with ours if it is on the same media but requires separate, independent action
to install it.

## Use for non-software goods and services

See [Universal considerations for all uses], above, which also apply.

### Uses we consider non-infringing

#### Websites

You may use the Word Marks and Logos, but not the Trade Dress, on your webpage
to show your support for the Project as long as:

* The website has branding that is easily distinguished from the Project Trade
Dress;
* Your own branding or naming is more prominent than any Project Marks;
* The Logos hyperlink to the Project website;
* The site does not mislead customers into thinking that either your website,
service, or product is our website, service, or product; and
* The site clearly states that you are not affiliated with or endorsed by the
Project.

#### Publications and presentations

You can use the Word Marks in book and article titles, and the Logo in
illustrations within the document, as long as the use does not suggest that we
have published, endorse, or agree with your work.

#### Events

You can use the Logo and signage from farmOS.org to promote the software and
Project at events.

### Uses for which we are granting a license

#### User groups

You can use the Word Marks as part of your user group name provided that:

* The main focus of the group is the software;
* Any software or services the group provides are without cost;
* The group does not make a profit;
* Any charge to attend meetings are to cover the cost of the venue, food and
drink only.

Note that the [Universal considerations for all uses], above, still apply,
specifically, that you may not use or register the Marks as part of your own
trademark, service mark, domain name, company name, trade name, product name or
service name.

#### Promotional goods

"Promotional goods" are non-software goods that use the Marks and that are
intended to advertise the Project, promote the Project, or show membership in
the Project community.

You may make stickers, hats, T-shirts, hoodies, and other promotional items for
free giveaway at open source conferences and events using only the designs found
on farmOS.org

### Uses we consider infringing without seeking further permission from us

We will likely consider using the Marks as part of a domain name or subdomain an
infringement of our Marks.

We would likely consider using the Marks on promotional goods for sale an
infringement of our Marks.

## General Information

### Trademark marking and legends

The first or most prominent mention of a Mark on a webpage, document, packaging,
or documentation should be accompanied by a symbol indicating whether the mark
is a registered trademark ("®") or an unregistered trademark ("™"). See our Trademark List for the correct symbol to use.

Also, if you are using our Marks in a way described in the sections "Uses for
which we are granting a license," please put following notice at the foot of the
page where you have used the Mark (or, if in a book, on the credits page), on
any packaging or labeling, and on advertising or marketing materials:

"farmOS is a registered trademark of Michel Stenta"

### What to do when you see abuse

If you are aware of any confusing use or misuse of the Marks in any way, we
would appreciate you bringing this to our attention. Please contact us as
described below so that we can investigate it further.

### Where to get further information

If you have any questions about this Policy, would like to speak with us about
the use of our Marks in ways not described in the Policy, or see any abuse of
our Marks, please [contact Michael Stenta].

## General considerations about trademarks and their use

### What trademark law is about

#### What is a trademark?

A trademark is a word, phrase, symbol or design, or a combination of words,
phrases, symbols or designs, that identifies and distinguishes the source of the
goods of one party from those of others. A service mark is the same as a
trademark, except that it identifies and distinguishes the source of a service
rather than a product. "Trade dress" or "get up" refers to the look and feel of
the packaging, which in this context can include the layout, colors, images, and
design choices in a web page. Throughout this Policy, the terms "trademark" and
"mark" refer to both trademarks, service marks and trade dress.

However, the use of a word is "not as a trademark" when it is used functionally
as part of the software program, for example, in a file, folder, directory, or
path name. Use in this way is not a trademark infringement.

#### What is "likelihood of confusion"?

There is trademark infringement if your use of a trademark has created a
"likelihood of confusion." This means using a trademark in a way that will
likely confuse or deceive the relevant consuming public about the source of a
product or service using the mark in question. For example, if the "Foo"
software extension removes all double spaces after periods, but someone else
later creates "Foo" software that adds a third space after periods, consumers
would be confused between the two and the newcomer will likely be a trademark
infringer. As another example, if a company makes "Foobar" software and a third
party offers training called "Foobar Certification," a person is likely to
believe, wrongly, that the certification is being offered by the makers of
Foobar software. The third party has likely misled consumers about the source of
its training and is a trademark infringer.

#### What is "nominative" use?

So-called "nominative use" (or "nominative fair use"), which is the name of the
doctrine under U.S. trademark law, allows the use of another's trademark where
it is necessary for understanding. Other countries' trademark laws also have
similar provisions. For example, a car repair shop that specializes in a
particular brand of automobile, VW for example, must be allowed to say that they
repair VW cars. Here is what you should consider when deciding whether your use
of a trademark is a nominative fair use:

* Whether you can identify the product or service in question without using the
trademark;
* Whether you are avoiding a likelihood of confusion in the way that you have
used the trademark; and
* Whether you have used only as much as is necessary to identify the product or
service.

With our "Foobar Certification" example above, the person offering the
certification would be allowed to say, under the nominative fair use doctrine,
that she is offering "Maude's Certification for Foobar software."

It is almost never the case that using a Logo will be a nominative fair use
since it will be a rare case where the logo is needed for strictly informational
purposes.

### Proper trademark use

These rules hold true for all trademarks, not just ours, so you should follow
them for our Marks as well as anyone else's.

#### Use of trademarks in text

**Always distinguish trademarks from surrounding text with at least initial
capital letters or in all capital letters.**

Note that with the farmOS mark, an exception is made in that the first letter
can be lowercase, but "OS" must be capitalized.

* Unacceptable: farmos
* Acceptable: FarmOS, FARMOS, farmOS

**Always use trademarks in their exact form with the correct spelling, neither
abbreviated, hyphenated, or combined with any other word or words.**

* Unacceptable: Farm OS, farm-OS
* Acceptable: farmOS

**Don't pluralize a trademark.**

* Unacceptable: I have seventeen farmOSes running on my farm.
* Acceptable: I have seventeen farmOS instances running on my farm.

**Don't use "a" or "the" to refer to an instance of the trademark.**

* Unacceptable: I put a farmOS on my mom's computer.
* Acceptable: I put a farmOS instance on my mom's computer.

**Always use a trademark as an adjective modifying a noun. You can see the nouns
we prefer under "Our trademarks."**

* Unacceptable: This is a farmOS. Anyone can install it.
* Acceptable: This is a farmOS application. Anyone can install it.

**Don't use a trademark as a verb. Trademarks are products or services, never
actions.**

* Unacceptable: I farmOSed my computer today!
* Acceptable: I installed farmOS on my computer today!

**Don't use a trademark as a possessive. Instead, the following noun should be
used in possessive form or the sentence reworded so there is no possessive.**

* Unacceptable: farmOS's interface is very clean.
* Acceptable: The farmOS dashboard's interface is very clean.

**Don't translate a trademark into another language.**

* Acceptable: Quiero instalar farmOS en mi sistema.
* Unacceptable: Quiero instalar granjaOS en mi sistema.

#### Use of Logos

You may not change any Logo except to scale it. This means you may not add
decorative elements, change the colors, change the proportions, distort it, add
elements, or combine it with other logos.

However, when the context requires the use of black-and-white graphics and the
logo is color, you may reproduce the logo in a manner that produces a
black-and-white image.

---

These guidelines are based on the Model Trademark Guidelines, available at 
[http://www.modeltrademarkguidelines.org], used under a Creative Commons
Attribution 3.0 Unported license:
[https://creativecommons.org/licenses/by/3.0/deed.en_US]

[Universal considerations for all uses]: #universal-considerations-for-all-uses
[contact Michael Stenta]: http://mstenta.net/contact
[http://www.modeltrademarkguidelines.org]: http://www.modeltrademarkguidelines.org
[https://creativecommons.org/licenses/by/3.0/deed.en_US]: https://creativecommons.org/licenses/by/3.0/deed.en_US

